# Built-in Stages

This directory contains the built-in stages to be used in MEDS-Transforms pipelines. Each stage will be
contained either in a singleton `.py` file or a subdirectory, keyed by stage name. When exposed as a
subdirectory, the directory may also contain static data examples of that stage in use that can aid in
documentation and testing of that stage.
